## Summary

This package removes common cover pages added by publishers or registries.

Examples of cover pages detected are:

- Researchgate
- JSTOR
- Scholarworks
- Emerald
- INFORMS
- AIS eLibrary
- Taylor and Francis

## pdf-prep

This package is included in many default setups.
